==========
 Indicium
==========

.. image:: https://readthedocs.org/projects/indicium/badge/?version=latest
   :target: https://indicium.readthedocs.org/en/latest
   :alt: Documentation Status

.. image:: https://img.shields.io/travis/aperezdc/indicium.svg?style=flat
   :target: https://travis-ci.org/aperezdc/indicium
   :alt: Build Status

.. image:: https://img.shields.io/coveralls/aperezdc/indicium/master.svg?style=flat
   :target: https://coveralls.io/r/aperezdc/indicium?branch=master
   :alt: Code Coverage

Pythonic, unified API to multiple key-value stores.
